==> yaml_bundles-1.0.2.tar.gz: yaml_bundles/tests/src/Kernel/ThirdPartySettingsTest.php <==
<?php

namespace Drupal\Tests\yaml_bundles\Kernel;

use Drupal\language\Entity\ConfigurableLanguage;
use Drupal\node\NodeTypeInterface;

/**
 * Tests the third party settings of yaml_bundles.bundle plugins.
 *
 * @group yaml_bundles
 */
class ThirdPartySettingsTest extends YamlBundlesKernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'allowed_formats',
    'content_translation',
    'datetime',
    'entity_reference_revisions',
    'field',
    'file',
    'filter',
    'image',
    'language',
    'link',
    'maxlength',
    'media',
    'media_library',
    'node',
    'options',
    'paragraphs',
    'system',
    'text',
    'user',
    'views',
    'yaml_bundles',
    'yaml_bundles_test',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    // Enable the Dutch language.
    ConfigurableLanguage::createFromLangcode('nl')->save();
  }

  /**
   * Tests the creation of a bundle using yaml_bundles.bundle plugins.
   */
  public function testThirdPartySettings(): void {
    $entity_type_manager = $this->container->get('entity_type.manager');
    $config_factory = $this->container->get('config.factory');
    $language_manager = $this->container->get('language_manager');
    $bundle_creator = $this->container->get('yaml_bundles.bundle_creator');

    $node_type_storage = $entity_type_manager->getStorage('node_type');
    $form_display_storage = $entity_type_manager->getStorage('entity_form_display');

    // Create the bundles from the yaml_bundles.bundle plugins.
    $bundle_creator->createBundles();

    // Assert the node type is created.
    $node_type = $node_type_storage->load('test_bundle');
    $this->assertInstanceOf(NodeTypeInterface::class, $node_type);

    // The third party settings to verify.
    $third_party_settings = [
      'field_summary' => [
        'widget_third_party_settings' => [
          'allowed_formats' => [
            'hide_help' => '1',
            'hide_guidelines' => '1',
          ],
          'maxlength' => [
            'maxlength_js' => 180,
            'maxlength_js_label' => 'The content is limited to @limit characters, remaining: <strong>@remaining</strong>',
            'maxlength_js_enforce' => FALSE,
          ],
        ],
      ],
    ];

    // Assert the third party settings are correctly configured for the
    // maxlength module.
    foreach ($third_party_settings as $field_name => $settings) {
      $form_display_component = $form_display_storage->load('node.test_bundle.default')->getComponent($field_name);
      $this->assertSame($form_display_component['third_party_settings'], $settings['widget_third_party_settings'], sprintf('The third party settings of the %s custom field are not correctly configured.', $field_name));
    }

    // Assert the third party settings are correctly translated.
    $language_manager->setConfigOverrideLanguage($language_manager->getLanguage('nl'));
    $form_display_storage->resetCache();
    $config_factory->reset();

    // The third party settings to verify.
    $translated_third_party_settings = [
      'field_summary' => [
        'widget_third_party_settings' => [
          'allowed_formats' => [
            'hide_help' => '1',
            'hide_guidelines' => '1',
          ],
          'maxlength' => [
            'maxlength_js' => 180,
            'maxlength_js_label' => 'De inhoud is beperkt tot @limit tekens, resterend: <strong>@remaining</strong>',
            'maxlength_js_enforce' => FALSE,
          ],
        ],
      ],
    ];

    // Assert the third party settings are correctly configured for the
    // maxlength module.
    foreach ($translated_third_party_settings as $field_name => $settings) {
      $form_display_component = $form_display_storage->load('node.test_bundle.default')->getComponent($field_name);
      $this->assertSame($form_display_component['third_party_settings'], $settings['widget_third_party_settings'], sprintf('The third party settings of the %s custom field are not correctly configured.', $field_name));
    }
  }

}

==> yaml_bundles-1.0.3.tar.gz: yaml_bundles/tests/src/Kernel/ThirdPartySettingsTest.php <==
<?php

namespace Drupal\Tests\yaml_bundles\Kernel;

use Drupal\language\Entity\ConfigurableLanguage;
use Drupal\node\NodeTypeInterface;

/**
 * Tests the third party settings of yaml_bundles.bundle plugins.
 *
 * @group yaml_bundles
 */
class ThirdPartySettingsTest extends YamlBundlesKernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'allowed_formats',
    'content_translation',
    'datetime',
    'entity_reference_revisions',
    'field',
    'file',
    'filter',
    'image',
    'language',
    'link',
    'maxlength',
    'media',
    'media_library',
    'node',
    'options',
    'paragraphs',
    'system',
    'text',
    'user',
    'views',
    'yaml_bundles',
    'yaml_bundles_test',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    // Enable the Dutch language.
    ConfigurableLanguage::createFromLangcode('nl')->save();
  }

  /**
   * Tests the creation of a bundle using yaml_bundles.bundle plugins.
   */
  public function testThirdPartySettings(): void {
    $entity_type_manager = $this->container->get('entity_type.manager');
    $config_factory = $this->container->get('config.factory');
    $language_manager = $this->container->get('language_manager');
    $bundle_creator = $this->container->get('yaml_bundles.bundle_creator');

    $node_type_storage = $entity_type_manager->getStorage('node_type');
    $form_display_storage = $entity_type_manager->getStorage('entity_form_display');

    // Create the bundles from the yaml_bundles.bundle plugins.
    $bundle_creator->createBundles();

    // Assert the node type is created.
    $node_type = $node_type_storage->load('test_bundle');
    static::assertInstanceOf(NodeTypeInterface::class, $node_type);

    // The third party settings to verify.
    $third_party_settings = [
      'field_summary' => [
        'widget_third_party_settings' => [
          'allowed_formats' => [
            'hide_help' => '1',
            'hide_guidelines' => '1',
          ],
          'maxlength' => [
            'maxlength_js' => 180,
            'maxlength_js_label' => 'The content is limited to @limit characters, remaining: <strong>@remaining</strong>',
            'maxlength_js_enforce' => FALSE,
          ],
        ],
      ],
    ];

    // Assert the third party settings are correctly configured for the
    // maxlength module.
    foreach ($third_party_settings as $field_name => $settings) {
      $form_display_component = $form_display_storage->load('node.test_bundle.default')->getComponent($field_name);
      static::assertSame($form_display_component['third_party_settings'], $settings['widget_third_party_settings'], sprintf('The third party settings of the %s custom field are not correctly configured.', $field_name));
    }

    // Assert the third party settings are correctly translated.
    $language_manager->setConfigOverrideLanguage($language_manager->getLanguage('nl'));
    $form_display_storage->resetCache();
    $config_factory->reset();

    // The third party settings to verify.
    $translated_third_party_settings = [
      'field_summary' => [
        'widget_third_party_settings' => [
          'allowed_formats' => [
            'hide_help' => '1',
            'hide_guidelines' => '1',
          ],
          'maxlength' => [
            'maxlength_js' => 180,
            'maxlength_js_label' => 'De inhoud is beperkt tot @limit tekens, resterend: <strong>@remaining</strong>',
            'maxlength_js_enforce' => FALSE,
          ],
        ],
      ],
    ];

    // Assert the third party settings are correctly configured for the
    // maxlength module.
    foreach ($translated_third_party_settings as $field_name => $settings) {
      $form_display_component = $form_display_storage->load('node.test_bundle.default')->getComponent($field_name);
      static::assertSame($form_display_component['third_party_settings'], $settings['widget_third_party_settings'], sprintf('The third party settings of the %s custom field are not correctly configured.', $field_name));
    }
  }

}
